@@ -116,7 +116,10 @@ class TaggedQuerySet(models.query.QuerySet):
         """
         if django.VERSION >= (3, 2):
             # Arguments changed to _filter_or_exclude(self, negate, args, kwargs)
-            args, kwargs = args
+            if len(args) == 2:
+                args, kwargs = args
+            elif set(kwargs.keys()) == {"args", "kwargs"}:
+                args, kwargs = kwargs["args"], kwargs["kwargs"]
 
         # TODO: Replace with custom lookups
         safe_fields, singletag_fields, tag_fields, field_lookup = _split_kwargs(
@@ -257,7 +260,11 @@ class TaggedQuerySet(models.query.QuerySet):
         # Make a subclass of TaggedQuerySet and the original class
         orig_cls = queryset.__class__
         new_cls_name = f"CastTagged{orig_cls.__name__}"
-        queryset.__class__ = type(new_cls_name, (cls, orig_cls), {},)
+        queryset.__class__ = type(
+            new_cls_name,
+            (cls, orig_cls),
+            {},
+        )
 
         return queryset
 
@@ -277,7 +284,9 @@ class TaggedQuerySet(models.query.QuerySet):
         q_filter = {f"{field_name}__in": getattr(instance, field_name).all()}
         similar = qs.annotate(
             tagulous_similarity=models.Count(
-                field_name, models.Q(**q_filter), distinct=True,
+                field_name,
+                models.Q(**q_filter),
+                distinct=True,
             )
         )
 
