@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django.contrib import admin
 
 from tests.tagulous_tests_app import models
@@ -14,11 +12,7 @@ class SimpleMixedTestAdmin(admin.ModelAdmin):
     list_display = ("name", "singletag", "tags")
     list_filter = ["singletag", "tags"]
     fields = ("name", "singletag", "tags")
-
-    # No links for changelist, to simplify tests
-    # Django 1.7 supports this being set to None, but Django 1.4 - 1.6 don't
-    # Therefore just set to invalid value for now
-    list_display_links = ["none"]
+    list_display_links = [None]
 
 
 class SimpleMixedTestInline(admin.TabularInline):
